import React, { Component } from 'react';
import PropTypes from 'prop-types';

export default class ImageCropper extends Component {
  static propTypes = {
    name: PropTypes.string,
    aspectRatio: PropTypes.number,
    width: PropTypes.number
  };

  static defaultProps = {
    name: 'image-cropper',
    aspectRatio: 1,
    width: 512
  };

  componentDidMount() {
    this.initialize();
  }

  initialize = () => {
    const $image = $(`.image-crop.${this.props.name} > img`);

    this.$image = $image;

    $image.cropper({
      aspectRatio: this.props.aspectRatio,
      zoomable: false,
      restore: true
    });

    const $inputImage = $(`#inputImage.${this.props.name}`);

    if (window.FileReader) {
      $inputImage.change(function() {
        const fileReader = new FileReader();

        const files = this.files;

        let file;

        if (!files.length) {
          return;
        }

        file = files[0];

        if (/^image\/\w+$/.test(file.type)) {
          fileReader.readAsDataURL(file);

          fileReader.onload = function() {
            $inputImage.val('');

            $image.cropper('reset', true).cropper('replace', this.result);
          };
        } else {
          toastr.error('이미지 파일을 선택해주세요.');
        }
      });
    } else {
      $inputImage.addClass("hide");
    }
  };

  reset = () => {
    this.$image.cropper('reset', true).cropper('replace', '/img/p3.jpg');
  };

  getBlob = (callback) => {
    this.resizeImage(this.$image.cropper('getDataURL'), this.props.width, this.props.width / this.props.aspectRatio, (dataUrl) => {
      this.resizeImage(this.$image.cropper('getDataURL'), this.props.width / 2, this.props.width / this.props.aspectRatio / 2, (halfDataUrl) => {
        callback(this.convertDataUrlToBlob(dataUrl), this.convertDataUrlToBlob(halfDataUrl));

        setTimeout(() => {
          this.reset();
        }, 1000);
      });
    });
  };

  convertDataUrlToBlob = (dataUrl) => {
    const splitDataUrl = dataUrl.split(',');

    const type = splitDataUrl[0].match(/:(.*?);/)[1];

    const data = atob(splitDataUrl[1]);

    var n = data.length;

    const uint8Data = new Uint8Array(n);

    while(n--) {
      uint8Data[n] = data.charCodeAt(n);
    }

    return new Blob([uint8Data], {
      type: type
    });
  };

  resizeImage = (dataUrl, width, height, callback) => {
    const image = new Image();

    image.onload = () => {
      const canvas = document.createElement('canvas');

      canvas.width = width;
      canvas.height = height;

      canvas.getContext("2d").drawImage(image, 0, 0, width, height);

      callback(canvas.toDataURL());
    };

    image.src = dataUrl;
  };

  render() {
    return (
      <div>
        <div className={`image-crop ${this.props.name}`}>
          <img src="/img/p3.jpg" />
        </div>
        <label className="btn btn-primary" style={{ marginTop: '10px' }}>
          <input type="file" accept="image/*" name="file" id="inputImage" className={`hide ${this.props.name}`} />
          이미지 업로드
        </label>
      </div>
    );
  }
}
